==> cloud-4.2.0.tar.gz: cloud/modules/cloud_dashboard/cloud_dashboard/src/molecules/EntityFormBlock.tsx <==
import EntityFormColumn from 'model/EntityFormColumn';
import BooleanInputBlock from 'molecules/BooleanInputBlock';
import JoinSelectBlock from 'molecules/JoinSelectBlock';
import KeyValueTableBlock from 'molecules/KeyValueTableBlock';
import LabelBlock from 'molecules/LabelBlock';
import MultiNumberInputBlock from 'molecules/MultiNumberInputBlock';
import NumberInputBlock from 'molecules/NumberInputBlock';
import RadioSelectBlock from 'molecules/RadioSelectBlock';
import StringInputBlock from 'molecules/StringInputBlock';
import TextareaBlock from 'molecules/TextareaBlock';
import TimeSelectBlock from 'molecules/TimeSelectBlock';
import UrlSelectBlock from 'molecules/UrlSelectBlock';
import { convertDateString } from 'service/utility';

const EntityFormBlock = ({ keyValueRecord, cloudContext, formData, setFormData }: {
  keyValueRecord: EntityFormColumn,
  cloudContext: string,
  formData: Record<string, any>,
  setFormData: (v: Record<string, any>) => void,
}) => {

  if (keyValueRecord.type === 'time') {
    const setHour = <T,>(v: T) => {
      const newFormData = JSON.parse(JSON.stringify(formData));
      newFormData[keyValueRecord.hourName] = v;
      setFormData(newFormData);
    }

    const setMinute = <T,>(v: T) => {
      const newFormData = JSON.parse(JSON.stringify(formData));
      newFormData[keyValueRecord.minuteName] = v;
      setFormData(newFormData);
    }

    return <TimeSelectBlock
      label={keyValueRecord.labelName}
      hour={formData[keyValueRecord.hourName]}
      setHour={setHour}
      minute={formData[keyValueRecord.minuteName]}
      setMinute={setMinute}
      required={!!keyValueRecord.required}
      readOnly={!!keyValueRecord.readOnly} />;
  }

  const value = formData[keyValueRecord.name];

  const setValue = <T,>(v: T) => {
    const newFormData = JSON.parse(JSON.stringify(formData));
    newFormData[keyValueRecord.name] = v;
    setFormData(newFormData);
  }

  switch (keyValueRecord.type) {
    case 'default':
      return !!keyValueRecord.readOnly
        ? <LabelBlock
          name={keyValueRecord.labelName}
          value={value} />
        : <StringInputBlock
          label={keyValueRecord.labelName}
          value={value}
          setValue={setValue}
          required={!!keyValueRecord.required}
          readOnly={!!keyValueRecord.readOnly} />;
    case 'number':
      return !!keyValueRecord.readOnly
        ? <LabelBlock
          name={keyValueRecord.labelName}
          value={`${value}`} />
        : <NumberInputBlock
          label={keyValueRecord.labelName}
          value={value}
          setValue={setValue}
          required={!!keyValueRecord.required}
          readOnly={!!keyValueRecord.readOnly} />;
    case 'number-array':
      return <MultiNumberInputBlock
        label={keyValueRecord.labelName}
        value={value}
        setValue={setValue}
        required={!!keyValueRecord.required}
        readOnly={!!keyValueRecord.readOnly} />;
    case 'join':
      return <JoinSelectBlock
        label={keyValueRecord.labelName}
        value={value}
        setValue={setValue}
        entityTypeId={keyValueRecord.info.entityTypeId}
        required={!!keyValueRecord.required}
        readOnly={!!keyValueRecord.readOnly} />;
    case 'select':
      return <UrlSelectBlock
        label={keyValueRecord.labelName}
        value={value}
        setValue={setValue}
        url={keyValueRecord.url}
        cloudContext={cloudContext}
        required={!!keyValueRecord.required}
        readOnly={!!keyValueRecord.readOnly} />;
    case 'textarea':
      return <TextareaBlock
        label={keyValueRecord.labelName}
        value={value}
        setValue={setValue}
        required={!!keyValueRecord.required}
        readOnly={!!keyValueRecord.readOnly} />;
    case 'key-value':
      return <KeyValueTableBlock
        label={keyValueRecord.labelName}
        value={value}
        setValue={setValue}
        required={!!keyValueRecord.required}
        readOnly={!!keyValueRecord.readOnly} />;
    case 'check':
      return <BooleanInputBlock
        label={keyValueRecord.labelName}
        value={value}
        setValue={setValue}
        required={!!keyValueRecord.required}
        readOnly={!!keyValueRecord.readOnly} />;
    case 'radio':
      return <RadioSelectBlock
        label={keyValueRecord.labelName}
        value={value}
        setValue={(s: string) => {
          setValue(s);
        }}
        valueList={keyValueRecord.value}
        orientation={keyValueRecord.orientation}
        required={!!keyValueRecord.required}
        readOnly={!!keyValueRecord.readOnly} />;
    case 'datetime':
      return <LabelBlock
        name={keyValueRecord.labelName}
        value={convertDateString(value)} />;
    default:
      return <></>;
  }
}

export default EntityFormBlock;

==> cloud-4.3.0.tar.gz: cloud/modules/cloud_dashboard/cloud_dashboard/src/molecules/EntityFormBlock.tsx <==
import EntityFormColumn from 'model/EntityFormColumn';
import BooleanInputBlock from 'molecules/BooleanInputBlock';
import DateTimeInputBlock from 'molecules/DateTimeInputBlock';
import FileInputBlock from 'molecules/FileInputBlock';
import JoinSelectBlock from 'molecules/JoinSelectBlock';
import KeyValueTableBlock from 'molecules/KeyValueTableBlock';
import LabelBlock from 'molecules/LabelBlock';
import MultiNumberInputBlock from 'molecules/MultiNumberInputBlock';
import MultiStringInputBlock from 'molecules/MultiStringInputBlock';
import NumberInputBlock from 'molecules/NumberInputBlock';
import PermissionInputBlock from 'molecules/PermissionInputBlock';
import RadioSelectBlock from 'molecules/RadioSelectBlock';
import SelectBlock from 'molecules/SelectBlock';
import StringInputBlock from 'molecules/StringInputBlock';
import TextareaBlock from 'molecules/TextareaBlock';
import TimeSelectBlock from 'molecules/TimeSelectBlock';
import UrlMultiSelectBlock from 'molecules/UrlMultiSelectBlock';
import UrlSelectBlock from 'molecules/UrlSelectBlock';
import { convertDateString } from 'service/utility';

const EntityFormBlock = ({ keyValueRecord, cloudContext, formData, setFormData }: {
  keyValueRecord: EntityFormColumn,
  cloudContext: string,
  formData: Record<string, any>,
  setFormData: (v: Record<string, any>) => void,
}) => {

  if (keyValueRecord.type === 'time') {
    const setHour = <T,>(v: T) => {
      const newFormData = JSON.parse(JSON.stringify(formData));
      newFormData[keyValueRecord.hourName] = v;
      setFormData(newFormData);
    }

    const setMinute = <T,>(v: T) => {
      const newFormData = JSON.parse(JSON.stringify(formData));
      newFormData[keyValueRecord.minuteName] = v;
      setFormData(newFormData);
    }

    return <TimeSelectBlock
      label={keyValueRecord.labelName}
      hour={formData[keyValueRecord.hourName]}
      setHour={setHour}
      minute={formData[keyValueRecord.minuteName]}
      setMinute={setMinute}
      required={!!keyValueRecord.required}
      readOnly={!!keyValueRecord.readOnly} />;
  }

  const value = formData[keyValueRecord.name];

  const setValue = <T,>(v: T) => {
    const newFormData = {...formData};
    newFormData[keyValueRecord.name] = v;
    setFormData(newFormData);
  }

  switch (keyValueRecord.type) {
    case 'default':
      return !!keyValueRecord.readOnly
        ? <LabelBlock
          name={keyValueRecord.labelName}
          value={value} />
        : <StringInputBlock
          label={keyValueRecord.labelName}
          value={value}
          setValue={setValue}
          required={!!keyValueRecord.required}
          readOnly={!!keyValueRecord.readOnly} />;
    case 'number':
      return !!keyValueRecord.readOnly
        ? <LabelBlock
          name={keyValueRecord.labelName}
          value={`${value}`} />
        : <NumberInputBlock
          label={keyValueRecord.labelName}
          value={value}
          setValue={setValue}
          required={!!keyValueRecord.required}
          readOnly={!!keyValueRecord.readOnly} />;
    case 'number-array':
      return <MultiNumberInputBlock
        label={keyValueRecord.labelName}
        value={value}
        setValue={setValue}
        required={!!keyValueRecord.required}
        readOnly={!!keyValueRecord.readOnly} />;
    case 'join':
      return <JoinSelectBlock
        label={keyValueRecord.labelName}
        value={value}
        setValue={setValue}
        entityTypeId={keyValueRecord.info.entityTypeId}
        keyColumn={keyValueRecord.info.keyColumn}
        optionLabel={keyValueRecord.info.label ?? '{name}'}
        required={!!keyValueRecord.required}
        readOnly={!!keyValueRecord.readOnly} />;
    case 'select':
      return <UrlSelectBlock
        label={keyValueRecord.labelName}
        value={value}
        setValue={setValue}
        formData={formData}
        url={keyValueRecord.url}
        cloudContext={cloudContext}
        required={!!keyValueRecord.required}
        readOnly={!!keyValueRecord.readOnly} />;
    case 'select-local':
      return <SelectBlock
        label={keyValueRecord.labelName}
        value={value}
        setValue={setValue}
        recordList={keyValueRecord.value.map((pair) => {
          return { label: pair.labelName, value: pair.name };
        })}
        required={!!keyValueRecord.required} />;
    case 'multi-select':
      return <UrlMultiSelectBlock
        label={keyValueRecord.labelName}
        value={value}
        setValue={setValue}
        url={keyValueRecord.url}
        cloudContext={cloudContext}
        required={!!keyValueRecord.required} />;
    case 'textarea':
      return <TextareaBlock
        label={keyValueRecord.labelName}
        value={value}
        setValue={setValue}
        required={!!keyValueRecord.required}
        readOnly={!!keyValueRecord.readOnly} />;
    case 'key-value':
      return <KeyValueTableBlock
        label={keyValueRecord.labelName}
        value={value}
        setValue={setValue}
        required={!!keyValueRecord.required}
        readOnly={!!keyValueRecord.readOnly} />;
    case 'radio':
      return <RadioSelectBlock
        label={keyValueRecord.labelName}
        value={value}
        setValue={(s: string) => {
          setValue(s);
        }}
        valueList={keyValueRecord.value}
        orientation={keyValueRecord.orientation}
        required={!!keyValueRecord.required}
        readOnly={!!keyValueRecord.readOnly} />;
    case 'datetime':
      return !!keyValueRecord.readOnly
        ? <LabelBlock
          name={keyValueRecord.labelName}
          value={convertDateString(value)} />
        : <DateTimeInputBlock
          label={keyValueRecord.labelName}
          value={value}
          setValue={setValue}
          required={!!keyValueRecord.required} />;
    case 'cost':
      return <LabelBlock
        name={keyValueRecord.labelName}
        value={`$${value}`} />;
    case 'boolean':
      return !!keyValueRecord.readOnly
        ? <LabelBlock
          name={keyValueRecord.labelName}
          value={
            (typeof keyValueRecord.labels === 'undefined'
              ? ['True', 'False']
              : keyValueRecord.labels)[
            !!(value) ? 0 : 1
            ]
          } />
        : <BooleanInputBlock
          label={keyValueRecord.labelName}
          value={value}
          setValue={setValue}
          required={!!keyValueRecord.required}
          readOnly={!!keyValueRecord.readOnly} />;
    case 'array':
      return !!keyValueRecord.readOnly
        ? <LabelBlock
          name={keyValueRecord.labelName}
          value={(value as string[]).join(', ')} />
        : <MultiStringInputBlock
          label={keyValueRecord.labelName}
          value={value}
          setValue={setValue}
          required={!!keyValueRecord.required}
          readOnly={!!keyValueRecord.readOnly} />;
    case 'sg_permission':
      return <PermissionInputBlock
        label={keyValueRecord.labelName}
        value={value}
        setValue={setValue} />;
    case 'file':
      return <FileInputBlock
        label={keyValueRecord.labelName}
        value={value}
        setValue={setValue} />;
    default:
      return <></>;
  }
}

export default EntityFormBlock;
